@@ -16,6 +16,7 @@ from testflows._core.cli.arg.common import epilog
 from testflows._core.cli.arg.common import HelpFormatter
 from testflows._core.cli.arg.handlers.handler import Handler as HandlerBase
 from testflows._core.cli.arg.handlers.transform.nice import Handler as nice_handler
+from testflows._core.cli.arg.handlers.transform.brisk import Handler as brisk_handler
 from testflows._core.cli.arg.handlers.transform.short import Handler as short_handler
 from testflows._core.cli.arg.handlers.transform.dots import Handler as dots_handler
 from testflows._core.cli.arg.handlers.transform.compact import Handler as compact_handler
@@ -39,6 +40,7 @@ class Handler(HandlerBase):
         transform_commands.required = True
         raw_handler.add_command(transform_commands)
         nice_handler.add_command(transform_commands)
+        brisk_handler.add_command(transform_commands)
         short_handler.add_command(transform_commands)
         slick_handler.add_command(transform_commands)
         classic_handler.add_command(transform_commands)
