@@ -18,7 +18,7 @@ from testflows._core.test import TestStep, TestCase, TestSuite, TestModule, Test
 from testflows._core.test import Context, SharedContext
 from testflows._core.test import Feature, Background, Scenario, Example, Outline
 from testflows._core.test import Critical, Major, Minor, Check, Given, When, Then, And, But, By, Finally, Cleanup
-from testflows._core.test import TestFeature, TestScenario, TestCheck, loads, ordered, retry, retries
+from testflows._core.test import TestFeature, TestScenario, TestCheck, loads, ordered, retry, retries, repeat, repeats
 from testflows._core.has import has
 from testflows._core.flags import Flags
 from testflows._core.objects import OK, XOK, Fail, XFail, Skip, Error, XError, Null, XNull
@@ -38,7 +38,7 @@ from testflows._core.funcs import attribute, requirement, tag
 from testflows._core.funcs import input, current_time
 from testflows._core.funcs import message, exception, ok, fail, skip, err
 from testflows._core.funcs import result, null, xok, xfail, xerr, xnull, pause, getsattr
-from testflows._core.funcs import current_dir, current_module, load_module
+from testflows._core.funcs import current_dir, current_module, load_module, load_submodules
 from testflows._core.flags import TE, UT, SKIP, EOK, EFAIL, EERROR, ESKIP
 from testflows._core.flags import XOK, XFAIL, XERROR, XNULL
 from testflows._core.flags import FAIL_NOT_COUNTED, ERROR_NOT_COUNTED, NULL_NOT_COUNTED
